@@ -46,7 +46,11 @@ def test_plot():
                   spd_bins=np.linspace(0, 10, 4))
     windrose.axes[0].legend(loc='best')
     met.close()
-    return display.fig
+
+    try:
+        return display.fig
+    finally:
+        matplotlib.pyplot.close(display.fig)
 
 
 def test_errors():
@@ -127,6 +131,8 @@ def test_errors():
     assert display.fig is not None
     assert display.axes is not None
 
+    matplotlib.pyplot.close(fig=display.fig)
+
 
 def test_histogram_errors():
     files = sample_files.EXAMPLE_MET1
@@ -177,6 +183,8 @@ def test_histogram_errors():
     assert histdisplay.fig is not None
     assert histdisplay.axes is not None
 
+    matplotlib.pyplot.close(fig=histdisplay.fig)
+
 
 def test_xsection_errors():
     obj = arm.read_netcdf(sample_files.EXAMPLE_CEIL1)
@@ -193,6 +201,7 @@ def test_xsection_errors():
         display.plot_xsection(None, 'backscatter', x='time')
 
     obj.close()
+    matplotlib.pyplot.close(fig=display.fig)
 
 
 @pytest.mark.mpl_image_compare(tolerance=30)
@@ -217,7 +226,11 @@ def test_multidataset_plot_tuple():
     ax, fig = act.plotting.common.parse_ax_fig(ax=None, fig=None)
     obj.close()
     obj2.close()
-    return display.fig
+
+    try:
+        return display.fig
+    finally:
+        matplotlib.pyplot.close(display.fig)
 
 
 @pytest.mark.mpl_image_compare(tolerance=30)
@@ -238,7 +251,10 @@ def test_multidataset_plot_dict():
     obj.close()
     obj2.close()
 
-    return display.fig
+    try:
+        return display.fig
+    finally:
+        matplotlib.pyplot.close(display.fig)
 
 
 @pytest.mark.mpl_image_compare(tolerance=30)
@@ -254,7 +270,11 @@ def test_wind_rose():
     WindDisplay.set_rrng((0., 14))
 
     sonde_ds.close()
-    return WindDisplay.fig
+
+    try:
+        return WindDisplay.fig
+    finally:
+        matplotlib.pyplot.close(WindDisplay.fig)
 
 
 @pytest.mark.mpl_image_compare(tolerance=30)
@@ -269,7 +289,11 @@ def test_barb_sounding_plot():
     BarbDisplay.plot_barbs_from_spd_dir('deg', 'wspd', 'pres',
                                         num_barbs_x=20)
     sonde_ds.close()
-    return BarbDisplay.fig
+
+    try:
+        return BarbDisplay.fig
+    finally:
+        matplotlib.pyplot.close(BarbDisplay.fig)
 
 
 @pytest.mark.mpl_image_compare(tolerance=30)
@@ -281,7 +305,10 @@ def test_skewt_plot():
         skewt = SkewTDisplay(sonde_ds)
         skewt.plot_from_u_and_v('u_wind', 'v_wind', 'pres', 'tdry', 'dp')
         sonde_ds.close()
-        return skewt.fig
+        try:
+            return skewt.fig
+        finally:
+            matplotlib.pyplot.close(skewt.fig)
 
 
 @pytest.mark.mpl_image_compare(tolerance=30)
@@ -292,7 +319,10 @@ def test_skewt_plot_spd_dir():
         skewt = SkewTDisplay(sonde_ds, ds_name='act_datastream')
         skewt.plot_from_spd_and_dir('wspd', 'deg', 'pres', 'tdry', 'dp')
         sonde_ds.close()
-        return skewt.fig
+        try:
+            return skewt.fig
+        finally:
+            matplotlib.pyplot.close(skewt.fig)
 
 
 @pytest.mark.mpl_image_compare(tolerance=67)
@@ -319,7 +349,10 @@ def test_multi_skewt_plot():
                 j = 0
             elif j == 0:
                 j += 1
-        return skewt.fig
+        try:
+            return skewt.fig
+        finally:
+            matplotlib.pyplot.close(skewt.fig)
 
 
 @pytest.mark.mpl_image_compare(tolerance=31)
@@ -331,19 +364,27 @@ def test_xsection_plot():
     xsection.plot_xsection(None, 'backscatter', x='time', y='range',
                            cmap='coolwarm', vmin=0, vmax=320)
     visst_ds.close()
-    return xsection.fig
+
+    try:
+        return xsection.fig
+    finally:
+        matplotlib.pyplot.close(xsection.fig)
 
 
 @pytest.mark.mpl_image_compare(tolerance=30)
 def test_xsection_plot_map():
     radar_ds = arm.read_netcdf(
-        sample_files.EXAMPLE_VISST, combine='nested')
+        sample_files.EXAMPLE_VISST, combine='nested', concat_dim='time')
+
     try:
         xsection = XSectionDisplay(radar_ds, figsize=(15, 8))
         xsection.plot_xsection_map(None, 'ir_temperature', vmin=220, vmax=300, cmap='Greys',
                                    x='longitude', y='latitude', isel_kwargs={'time': 0})
         radar_ds.close()
-        return xsection.fig
+        try:
+            return xsection.fig
+        finally:
+            matplotlib.pyplot.close(xsection.fig)
     except Exception:
         pass
 
@@ -354,10 +395,14 @@ def test_geoplot():
         sample_files.EXAMPLE_SONDE1)
     try:
         geodisplay = GeographicPlotDisplay({'sgpsondewnpnC1.b1': sonde_ds})
-        geodisplay.geoplot('tdry', marker='.', cartopy_feature=['STATES', 'LAND', 'OCEAN', 'COASTLINE',
-                                                                'BORDERS', 'LAKES', 'RIVERS'],
+        geodisplay.geoplot('tdry', marker='.', cartopy_feature=['STATES', 'LAND', 'OCEAN',
+                                                                'COASTLINE', 'BORDERS',
+                                                                'LAKES', 'RIVERS'],
                            text={'Ponca City': [-97.0725, 36.7125]})
-        return geodisplay.fig
+        try:
+            return geodisplay.fig
+        finally:
+            matplotlib.pyplot.close(geodisplay.fig)
     except Exception:
         pass
     sonde_ds.close()
@@ -372,7 +417,10 @@ def test_stair_graph():
     histdisplay.plot_stairstep_graph('tdry', bins=np.arange(-60, 10, 1))
     sonde_ds.close()
 
-    return histdisplay.fig
+    try:
+        return histdisplay.fig
+    finally:
+        matplotlib.pyplot.close(histdisplay.fig)
 
 
 @pytest.mark.mpl_image_compare(tolerance=30)
@@ -386,7 +434,10 @@ def test_stair_graph_sorted():
         sortby_bins=np.linspace(0, 10000., 6))
     sonde_ds.close()
 
-    return histdisplay.fig
+    try:
+        return histdisplay.fig
+    finally:
+        matplotlib.pyplot.close(histdisplay.fig)
 
 
 @pytest.mark.mpl_image_compare(tolerance=30)
@@ -398,7 +449,10 @@ def test_stacked_bar_graph():
     histdisplay.plot_stacked_bar_graph('tdry', bins=np.arange(-60, 10, 1))
     sonde_ds.close()
 
-    return histdisplay.fig
+    try:
+        return histdisplay.fig
+    finally:
+        matplotlib.pyplot.close(histdisplay.fig)
 
 
 @pytest.mark.mpl_image_compare(tolerance=30)
@@ -412,7 +466,10 @@ def test_stacked_bar_graph2():
     histdisplay.set_xrng([-70, 0])
     sonde_ds.close()
 
-    return histdisplay.fig
+    try:
+        return histdisplay.fig
+    finally:
+        matplotlib.pyplot.close(histdisplay.fig)
 
 
 @pytest.mark.mpl_image_compare(tolerance=30)
@@ -426,7 +483,10 @@ def test_stacked_bar_graph_sorted():
         sortby_bins=np.linspace(0, 10000., 6))
     sonde_ds.close()
 
-    return histdisplay.fig
+    try:
+        return histdisplay.fig
+    finally:
+        matplotlib.pyplot.close(histdisplay.fig)
 
 
 @pytest.mark.mpl_image_compare(tolerance=30)
@@ -440,7 +500,10 @@ def test_heatmap():
         y_bins=np.linspace(0, 10000., 50), cmap='coolwarm')
     sonde_ds.close()
 
-    return histdisplay.fig
+    try:
+        return histdisplay.fig
+    finally:
+        matplotlib.pyplot.close(histdisplay.fig)
 
 
 @pytest.mark.mpl_image_compare(tolerance=30)
@@ -454,7 +517,10 @@ def test_size_distribution():
     my_fake_ds = xr.Dataset({'bins': bins, 'ydata': y_array})
     histdisplay = HistogramDisplay(my_fake_ds)
     histdisplay.plot_size_distribution('ydata', 'bins', set_title='Fake distribution.')
-    return histdisplay.fig
+    try:
+        return histdisplay.fig
+    finally:
+        matplotlib.pyplot.close(histdisplay.fig)
 
 
 @pytest.mark.mpl_image_compare(tolerance=30)
@@ -475,10 +541,14 @@ def test_contour():
     display = ContourDisplay(data, figsize=(8, 8))
     display.create_contour(fields=fields, time=time, levels=50,
                            contour='contour', cmap='viridis')
-    display.plot_vectors_from_spd_dir(fields=wind_fields, time=time, mesh=True, grid_delta=(0.1, 0.1))
+    display.plot_vectors_from_spd_dir(fields=wind_fields, time=time, mesh=True,
+                                      grid_delta=(0.1, 0.1))
     display.plot_station(fields=station_fields, time=time, markersize=7, color='red')
 
-    return display.fig
+    try:
+        return display.fig
+    finally:
+        matplotlib.pyplot.close(display.fig)
 
 
 @pytest.mark.mpl_image_compare(tolerance=30)
@@ -498,7 +568,10 @@ def test_contour_stamp():
     display.create_contour(fields=stamp_fields, time=time, levels=50,
                            alpha=0.5, twod_dim_value=5)
 
-    return display.fig
+    try:
+        return display.fig
+    finally:
+        matplotlib.pyplot.close(display.fig)
 
 
 @pytest.mark.mpl_image_compare(tolerance=30)
@@ -519,10 +592,14 @@ def test_contour2():
     display = ContourDisplay(data, figsize=(8, 8))
     display.create_contour(fields=fields, time=time, levels=50,
                            contour='contour', cmap='viridis')
-    display.plot_vectors_from_spd_dir(fields=wind_fields, time=time, mesh=False, grid_delta=(0.1, 0.1))
+    display.plot_vectors_from_spd_dir(fields=wind_fields, time=time, mesh=False,
+                                      grid_delta=(0.1, 0.1))
     display.plot_station(fields=station_fields, time=time, markersize=7, color='pink')
 
-    return display.fig
+    try:
+        return display.fig
+    finally:
+        matplotlib.pyplot.close(display.fig)
 
 
 @pytest.mark.mpl_image_compare(tolerance=30)
@@ -544,10 +621,14 @@ def test_contourf():
     display = ContourDisplay(data, figsize=(8, 8))
     display.create_contour(fields=fields, time=time, levels=50,
                            contour='contourf', cmap='viridis')
-    display.plot_vectors_from_spd_dir(fields=wind_fields, time=time, mesh=True, grid_delta=(0.1, 0.1))
+    display.plot_vectors_from_spd_dir(fields=wind_fields, time=time, mesh=True,
+                                      grid_delta=(0.1, 0.1))
     display.plot_station(fields=station_fields, time=time, markersize=7, color='red')
 
-    return display.fig
+    try:
+        return display.fig
+    finally:
+        matplotlib.pyplot.close(display.fig)
 
 
 @pytest.mark.mpl_image_compare(tolerance=30)
@@ -569,10 +650,14 @@ def test_contourf2():
     display = ContourDisplay(data, figsize=(8, 8))
     display.create_contour(fields=fields, time=time, levels=50,
                            contour='contourf', cmap='viridis')
-    display.plot_vectors_from_spd_dir(fields=wind_fields, time=time, mesh=False, grid_delta=(0.1, 0.1))
+    display.plot_vectors_from_spd_dir(fields=wind_fields, time=time, mesh=False,
+                                      grid_delta=(0.1, 0.1))
     display.plot_station(fields=station_fields, time=time, markersize=7, color='pink')
 
-    return display.fig
+    try:
+        return display.fig
+    finally:
+        matplotlib.pyplot.close(display.fig)
 
 
 # Due to issues with pytest-mpl, for now we just test to see if it runs
@@ -586,7 +671,10 @@ def test_time_height_scatter():
 
     sonde_ds.close()
 
-    return display.fig
+    try:
+        return display.fig
+    finally:
+        matplotlib.pyplot.close(display.fig)
 
 
 @pytest.mark.mpl_image_compare(tolerance=30)
@@ -613,7 +701,10 @@ def test_qc_bar_plot():
 
     ds_object.close()
 
-    return display.fig
+    try:
+        return display.fig
+    finally:
+        matplotlib.pyplot.close(display.fig)
 
 
 @pytest.mark.mpl_image_compare(tolerance=30)
@@ -626,7 +717,10 @@ def test_2d_as_1d():
     obj.close()
     del obj
 
-    return display.fig
+    try:
+        return display.fig
+    finally:
+        matplotlib.pyplot.close(display.fig)
 
 
 @pytest.mark.mpl_image_compare(tolerance=30)
@@ -641,7 +735,10 @@ def test_fill_between():
     obj.close()
     del obj
 
-    return display.fig
+    try:
+        return display.fig
+    finally:
+        matplotlib.pyplot.close(display.fig)
 
 
 @pytest.mark.mpl_image_compare(tolerance=30)
@@ -657,7 +754,10 @@ def test_qc_flag_block_plot():
     obj.close()
     del obj
 
-    return display.fig
+    try:
+        return display.fig
+    finally:
+        matplotlib.pyplot.close(display.fig)
 
 
 @pytest.mark.mpl_image_compare(tolerance=30)
@@ -678,7 +778,10 @@ def test_assessment_overplot():
     display.plot(var_name, day_night_background=True, assessment_overplot=True)
 
     ds.close()
-    return display.fig
+    try:
+        return display.fig
+    finally:
+        matplotlib.pyplot.close(display.fig)
 
 
 @pytest.mark.mpl_image_compare(tolerance=30)
@@ -701,7 +804,10 @@ def test_assessment_overplot_multi():
                  label=var_name2, assessment_overplot=True)
 
     ds.close()
-    return display.fig
+    try:
+        return display.fig
+    finally:
+        matplotlib.pyplot.close(display.fig)
 
 
 @pytest.mark.mpl_image_compare(tolerance=30)
@@ -712,7 +818,10 @@ def test_plot_barbs_from_u_v():
     BarbDisplay.plot_barbs_from_u_v('u_wind', 'v_wind', 'pres',
                                     num_barbs_x=20)
     sonde_ds.close()
-    return BarbDisplay.fig
+    try:
+        return BarbDisplay.fig
+    finally:
+        matplotlib.pyplot.close(BarbDisplay.fig)
 
 
 @pytest.mark.mpl_image_compare(tolerance=30)
@@ -734,7 +843,10 @@ def test_plot_barbs_from_u_v2():
     BarbDisplay.plot_barbs_from_u_v('xdata', 'ydata', None, num_barbs_x=20,
                                     num_barbs_y=20, set_title='test plot', cmap='jet')
     fake_obj.close()
-    return BarbDisplay.fig
+    try:
+        return BarbDisplay.fig
+    finally:
+        matplotlib.pyplot.close(BarbDisplay.fig)
 
 
 @pytest.mark.mpl_image_compare(tolerance=30)
@@ -742,5 +854,7 @@ def test_2D_timeseries_plot():
     obj = arm.read_netcdf(sample_files.EXAMPLE_CEIL1)
     display = TimeSeriesDisplay(obj)
     display.plot('backscatter', y_rng=[0, 5000], use_var_for_y='range')
-    matplotlib.pyplot.show()
-    return display.fig
+    try:
+        return display.fig
+    finally:
+        matplotlib.pyplot.close(display.fig)
